@@ -1,27 +1,15 @@
-/* This file is part of the KDE project
- * Copyright (C) 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KCOLORSCHEME_H
 #define KCOLORSCHEME_H
 
 #include <kconfigwidgets_export.h>
-#include <ksharedconfig.h>
+#include <KSharedConfig>
 
 #include <QExplicitlySharedDataPointer>
 
@@ -123,8 +111,14 @@ public:
          * @since 5.19
          */
         Complementary,
+        /**
+         * Colors for header areas that thould be used both by the top toolbar and the titlebar titlebar.
+         * @since 5.69
+         */
+        Header,
         /**
          * Number of color sets.
+         * Note: don't use this
          * @since 5.65
          */
         NColorSets
